# inline-resource-plugin
> A webpack plugin to make css/js resource inline in the html with inline-source.

## Install

```bash
$ npm install inline-resource-plugin --save-dev
```

## example

```html
<!-- ./build/hello.html -->
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>test</title>
    <link href="inline.css" inline>
    <script src="inline.js" inline></script>
</head>
<body>
<div class="container">
    <h1>hello world!</h1>
</div>
</body>
</html>
```

```js
//Be careful,this plugin doesn't support ES6 until now
/* ./src/inline.js */
function Person() {
}

Person.prototype.sayHello = function () {
    var word = 'hello';
    console.log(word);
};
```

```css
/* ./src/inline.css */
.container {
    border: 1px solid #000000;
}
```

Output:
```html
<!-- ./build/hello.html -->
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>test</title>
    <style>.container{border:1px solid #000}</style>
    <script>function Person(){}Person.prototype.sayHello=function(){var o="hello";console.log(o)};</script>
</head>
<body>
<div class="container">
    <h1>hello world!</h1>
</div>
</body>
</html>
```

## Usage
Available `options` include:
- `compress`: enable/disable compression (default `true`)
- `rootpath`: path used for resolving inlineable paths (default `process.cwd()`)
- `list`: This is a non-required option.If you decide to use the other plugins such as HtmlWebpackPlugin,you can ignore this option and we will try to read template from the assets which are generated by the other plugins.Or you can pass the path of template (glob support).
- `include`: the file which you want to execute inline task (non-required, default `/\.html$|\.ejs$/i`).

```javascript
//webpack.config.js
var HtmlWebpackPlugin = require('html-webpack-plugin');
var InlineResource = require('inline-resource-plugin');

module.exports = {
    entry: {
        hello: './src/hello.js'
    },
    output: {
        path: './build',
        filename: '[name].js'
    },
    plugins: [
        new HtmlWebpackPlugin({
            filename: 'hello.html',
            template: './src/hello.html',
            inject: 'body'
        }),
        new InlineResource({
            compress: true,
            rootpath: './src',
            //if you have only one html file,this list option can also be a character string.such as
            //list: './src/hello.html'
            //it can also be a file path string or file path array.such as
            //list: ['./src/hello.html']
            //or use glob,such as
            //list: ['./src/*.html']
            include: /\.html$|\.ejs$/i
        })
    ]
};
```

note: You can find this demo in the example directory.